import type { GossipsubMessage } from "@chainsafe/libp2p-gossipsub";
import type { EventCallback, StreamHandler } from "@libp2p/interface";
import { Logger, type LoggerOptions } from "@sfroment/logger";
import { DRPNetworkNode, type DRPNetworkNodeConfig } from "@sfroment/network";
import { type ACL, type DRP, DRPObject } from "@sfroment/object";
import { type DRPCredentialConfig, DRPCredentialStore, DRPObjectStore } from "./store/index.js";
export interface DRPNodeConfig {
    log_config?: LoggerOptions;
    network_config?: DRPNetworkNodeConfig;
    credential_config?: DRPCredentialConfig;
}
export declare let log: Logger;
export declare class DRPNode {
    config?: DRPNodeConfig;
    objectStore: DRPObjectStore;
    networkNode: DRPNetworkNode;
    credentialStore: DRPCredentialStore;
    constructor(config?: DRPNodeConfig);
    start(): Promise<void>;
    restart(config?: DRPNodeConfig): Promise<void>;
    addCustomGroup(group: string): void;
    addCustomGroupMessageHandler(group: string, handler: EventCallback<CustomEvent<GossipsubMessage>>): void;
    sendGroupMessage(group: string, data: Uint8Array): Promise<void>;
    addCustomMessageHandler(protocol: string | string[], handler: StreamHandler): Promise<void>;
    sendCustomMessage(peerId: string, data: Uint8Array): Promise<void>;
    createObject(options: {
        drp?: DRP;
        acl?: ACL;
        id?: string;
        sync?: {
            enabled: boolean;
            peerId?: string;
        };
    }): Promise<DRPObject>;
    connectObject(options: {
        id: string;
        drp?: DRP;
        sync?: {
            peerId?: string;
        };
    }): Promise<DRPObject>;
    subscribeObject(id: string): Promise<void>;
    unsubscribeObject(id: string, purge?: boolean): void;
    syncObject(id: string, peerId?: string): Promise<void>;
}
//# sourceMappingURL=index.d.ts.map